@@ -1,5 +1,5 @@
 """
-  Copyright (C) 2020 Seerbit
+  Copyright (C) 2022 SeerBit
 
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -14,10 +14,10 @@
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
  """
-from seerbit.interface.app_interface import ISeerbit, IClientConstants
+from seerbit.interface.app_interface import ISeerBit, IClientConstants
 
 
-class Seerbit(ISeerbit, IClientConstants):
+class SeerBit(ISeerBit, IClientConstants):
 
     @property
     def api_version(self):
